#!/bin/bash
set -euo pipefail

PYTEST_PLAYWRIGHT_VERSION="0.3.3"

pushd "$VENV_PATH" || exit 1
bin/pip install "pytest-playwright==$PYTEST_PLAYWRIGHT_VERSION"
bin/pip install "pytest-repeat"
popd
